@@ -19,10 +19,22 @@ lint_inputs <- function(lon = NULL, lat = NULL, format) {
 # - degree symbols
 # - masculine ordinal indicator
 # - rare separators
-scrub <- function(x) {
-  gsub(
-    "\u0027\u0027|\u2018\u2018|\u2019\u2019|\u02BC\u02BC|\u0060\u0060|\u00BB|\u201C|\u201D|\u2033|\u3003|\u301E|\u301F|\u0022|\u02BA|\u02DD|\u275E|\u030B|\u030E|\u030F|\u05F4|\u2018|\u2019|\u02BC|\u02C8|\u0060|\u030D|\u02B9|\u00B4|\u0301|\u0374|\u0384|\u2032|\u275C|\u05F3|\u055A|\u055B|\u055D|\u0599|\u059C|\u059D|\u059E|\u00B0|\u02DA|\u030A|\u2070|\u0366|\u05AF|\u00BA|d|g|\u003A", "'", x)
 
+scrub <- function(x) gsub("[^A-Za-z0-9\\.\\ ,'-]|d|g", "'", x)
+
+stop_form <- function() stop("format handling not ready yet")
+
+# Because of a std::regex's bug, all Rcpp functions hangs on Windows with MBCS
+# locale (#31). As a workaround for this, we can wrap the functions with
+# `withr::with_locale()` and force C locale temporarily. To ensure all the Rcpp
+# functions are wrapped with this, override `.Call()` inside the package.
+.Call <- function(...) {
+  if (identical(tolower(Sys.info()[["sysname"]]), "windows")) {
+    withr::with_locale(
+      c(LC_COLLATE = "C"),
+      base::.Call(...)
+    )
+  } else {
+    base::.Call(...)
+  }
 }
-
-stop_form <- function() stop("format handling not ready yet")
\ No newline at end of file
